@@ -3,17 +3,35 @@
 #
 # == param
 # -file path of the uncompressed cytoband file
+# -species abbrevations of species. e.g. hg19 for human, mm10 for mouse. If this
+#          value is specified, the function will download cytoBand.txt.gz from
+#          UCSC website automatically.
 #
 # == details
-# The function read the cytoband data, sort the chromosome names and calculate the length of each chromosome.
+# The function read the cytoband data, sort the chromosome names and calculate the length of each chromosome. 
+# By default, it is human hg19 cytoband data.
 #
 # == values
 #
 # -df Original data frame for cytoband data
 # -chromosome sorted chromosome names
 # -chr.len length of chromosomes. Order are same as ``chromosome``
-read.cytoband = function(file = paste(system.file(package = "circlize"), "/extdata/cytoBand.txt", sep="")) {
-	d = read.table(file, colClasses = c("character", "numeric", "numeric", "character", "character"))
+read.cytoband = function(file = paste(system.file(package = "circlize"), "/extdata/cytoBand.txt", sep=""), species = NULL) {
+	
+	if(!is.null(species)) {
+		url = paste("http://hgdownload.cse.ucsc.edu/goldenPath/", species, "/database/cytoBand.txt.gz", sep = "")
+		file = paste(tempdir(), "/cytoBand.txt.gz", sep = "")
+		e = try(download.file(url, destfile = file, quiet = TRUE), silent = TRUE)
+		if(class(e) == "try-error") {
+			stop("Seems your species name is wrong or you cannot access the internet.\nIf possible, download cytoBand file from\n", url, "\nand use `read.cytoband(file)`.\n")
+		}
+	}
+	
+	if(grepl("\\.gz$", file)) {
+		file = gzfile(file)
+	}
+	
+	d = read.table(file, colClasses = c("character", "numeric", "numeric", "character", "character"), sep = "\t")
 	
 	chromosome = unique(d[[1]])
 	chromosome.ind = gsub("chr", "", chromosome)
