@@ -64,6 +64,7 @@ circos.trackPlotRegion = function(factors = NULL, x = NULL, y = NULL, ylim = NUL
 	# if there is no factors, default are all the available factors
 	if(is.null(factors)) {
 		factors = get.all.sector.index()
+		factors = factor(factors, levels = factors)
 	}
 	
     # although ``x`` and ``y`` are not necessary, but once they are set, they must
@@ -1123,6 +1124,9 @@ circos.trackHist = function(factors, x, track.height = circos.par("default.track
 #
 # == param
 # -file             cytoband file. By default it is the cytoband data for human
+# -species abbrevations of species. e.g. hg19 for human, mm10 for mouse. If this
+#          value is specified, the function will download cytoBand.txt.gz from
+#          UCSC website automatically.
 # -chromosome.index index for chromosome. The index is used only for subsetting, not for re-ordering.
 #                   The value should be 1, 2, ... or chr1, chr2, ...
 # -track.height     height for the track
@@ -1134,13 +1138,10 @@ circos.trackHist = function(factors, x, track.height = circos.par("default.track
 #
 # In fact, drawing ideogram with this package is really simple, you can look at the source code
 # of this function to get a clue.
-#
-# The cytoband data for human is downloaded from UCSC ftp site (http://hgdownload.cse.ucsc.edu/goldenPath/hg19/database/cytoBand.txt.gz),
-# it should be uncompressed.
-circos.initializeWithIdeogram = function(file = paste(system.file(package = "circlize"), "/extdata/cytoBand.txt", sep=""),
+circos.initializeWithIdeogram = function(file = paste(system.file(package = "circlize"), "/extdata/cytoBand.txt", sep=""), species = NULL,
     chromosome.index = NULL, track.height = 0.1) {
 	
-	cytoband = read.cytoband(file)
+	cytoband = read.cytoband(file, species = species)
 	d = cytoband$df
 	chromosome = cytoband$chromosome
 	
